pub trait Extend<T> {
// Required methods
fn reserve(&mut self, additional: usize);
fn push(&mut self, item: T);
}Expand description
A collection that can be used to receive the results of the [Path::extend][] method.
Note: There’s an open issue to add these methods to std’s Extend trait. If
that gets merged, we can drop this trait and use the std one instead.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".