pub struct SQLiteReader { /* private fields */ }Expand description
Reader to load stack graphs and partial paths from a SQLite database.
Implementations
Sourceimpl SQLiteReader
impl SQLiteReader
Sourcepub fn clear(&mut self)
pub fn clear(&mut self)
Clear all data that has been loaded into this reader instance. After this call, all existing handles from this reader are invalid.
Sourcepub fn clear_paths(&mut self)
pub fn clear_paths(&mut self)
Clear path data that has been loaded into this reader instance. After this call, all node handles remain valid, but all path data is invalid.
Sourcepub fn status_for_file<T: AsRef<str>>(
&mut self,
file: &str,
tag: Option<T>,
) -> Result<FileStatus>
pub fn status_for_file<T: AsRef<str>>( &mut self, file: &str, tag: Option<T>, ) -> Result<FileStatus>
Get the file’s status in the database. If a tag is provided, it must match or the file is reported missing.
Sourcepub fn list_all<'a>(&'a mut self) -> Result<Files<'a, ()>>
pub fn list_all<'a>(&'a mut self) -> Result<Files<'a, ()>>
Returns a Files value that can be used to iterate over all files in the database.
Sourcepub fn list_file_or_directory<'a>(
&'a self,
file_or_directory: &Path,
) -> Result<Files<'a, [String; 1]>>
pub fn list_file_or_directory<'a>( &'a self, file_or_directory: &Path, ) -> Result<Files<'a, [String; 1]>>
Returns a Files value that can be used to iterate over all descendants of a
file or directory in the database.
Sourcepub fn load_graph_for_file(&mut self, file: &str) -> Result<Handle<File>>
pub fn load_graph_for_file(&mut self, file: &str) -> Result<Handle<File>>
Ensure the graph for the given file is loaded.
pub fn load_graphs_for_file_or_directory( &mut self, file_or_directory: &Path, cancellation_flag: &dyn CancellationFlag, ) -> Result<()>
Sourcepub fn load_partial_path_extensions(
&mut self,
path: &PartialPath,
cancellation_flag: &dyn CancellationFlag,
) -> Result<()>
pub fn load_partial_path_extensions( &mut self, path: &PartialPath, cancellation_flag: &dyn CancellationFlag, ) -> Result<()>
Ensure all possible extensions for the given partial path are loaded.
Sourcepub fn get(&mut self) -> (&mut StackGraph, &mut PartialPaths, &mut Database)
pub fn get(&mut self) -> (&mut StackGraph, &mut PartialPaths, &mut Database)
Get the stack graph, partial paths arena, and path database for the currently loaded data.