pub trait Filter {
// Required methods
fn include_file(&self, graph: &StackGraph, file: &Handle<File>) -> bool;
fn include_node(&self, graph: &StackGraph, node: &Handle<Node>) -> bool;
fn include_edge(
&self,
graph: &StackGraph,
source: &Handle<Node>,
sink: &Handle<Node>,
) -> bool;
fn include_partial_path(
&self,
graph: &StackGraph,
paths: &PartialPaths,
path: &PartialPath,
) -> bool;
}Required Methods
Sourcefn include_file(&self, graph: &StackGraph, file: &Handle<File>) -> bool
fn include_file(&self, graph: &StackGraph, file: &Handle<File>) -> bool
Return whether elements for the given file must be included.
Sourcefn include_node(&self, graph: &StackGraph, node: &Handle<Node>) -> bool
fn include_node(&self, graph: &StackGraph, node: &Handle<Node>) -> bool
Return whether the given node must be included. Nodes of excluded files are always excluded.
Sourcefn include_edge(
&self,
graph: &StackGraph,
source: &Handle<Node>,
sink: &Handle<Node>,
) -> bool
fn include_edge( &self, graph: &StackGraph, source: &Handle<Node>, sink: &Handle<Node>, ) -> bool
Return whether the given edge must be included. Edges via excluded nodes are always excluded.
Sourcefn include_partial_path(
&self,
graph: &StackGraph,
paths: &PartialPaths,
path: &PartialPath,
) -> bool
fn include_partial_path( &self, graph: &StackGraph, paths: &PartialPaths, path: &PartialPath, ) -> bool
Return whether the given path must be included. Paths via excluded nodes or edges are always excluded.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".